==> vue-badge-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/badge/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import "@dft-vue-2-opentiny/vue-theme/badge/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["isDot", "hidden", "type", "max", "value", "modelValue", "href", "target", "badgeClass", "offset", "data"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-badge__wrapper"
  }, [_vm.data ? _c("span", [_vm._v(_vm._s(_vm.data))]) : _vm._t("default"), !_vm.hidden && (_vm.state.content || _vm.state.content === 0 || _vm.isDot) ? _c("div", {
    staticClass: "tiny-badge",
    class: [_vm.isDot ? "tiny-badge--default" : "", _vm.state.isOverstep ? "tiny-badge--max" : "", _vm.type ? "tiny-badge--" + _vm.type : "", _vm.badgeClass || ""],
    style: {
      transform: "translate(\n        " + _vm.offset[0] + (typeof _vm.offset[0] === "number" ? "px" : "") + ",\n        " + _vm.offset[1] + (typeof _vm.offset[1] === "number" ? "px" : "") + "\n      )"
    }
  }, [_vm._t("content", [_vm.state.href ? _c("a", {
    attrs: {
      "href": _vm.state.href,
      "target": _vm.target,
      "rel": "noopener noreferrer"
    }
  }, [_vm._v(_vm._s(_vm.state.content))]) : _vm._e(), !_vm.state.href ? _c("span", {
    staticClass: "tiny-badge__content-text"
  }, [_vm._v(_vm._s(_vm.state.content))]) : _vm._e()])], 2) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-badge-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/badge/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme/badge/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["isDot", "hidden", "type", "max", "value", "modelValue", "href", "target", "badgeClass", "offset", "data"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-badge__wrapper"
  }, [_vm.data ? _c("span", [_vm._v(_vm._s(_vm.data))]) : _vm._t("default"), !_vm.hidden && (_vm.state.content || _vm.state.content === 0 || _vm.isDot) ? _c("div", {
    staticClass: "tiny-badge",
    class: [_vm.isDot ? "tiny-badge--default" : "", _vm.state.isOverstep ? "tiny-badge--max" : "", _vm.type ? "tiny-badge--" + _vm.type : "", _vm.badgeClass || ""],
    style: !_vm.isDot ? _vm.state.transform : ""
  }, [_vm._t("content", function() {
    return [_vm.state.href ? _c("a", {
      attrs: {
        "href": _vm.state.href,
        "target": _vm.target,
        "rel": "noopener noreferrer"
      }
    }, [_vm._v(_vm._s(_vm.state.content))]) : _vm._e(), !_vm.state.href ? _c("span", {
      staticClass: "tiny-badge__content-text"
    }, [_vm._v(_vm._s(_vm.state.content))]) : _vm._e()];
  })], 2) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
